@@ -1,5 +1,5 @@
 package GeoIP2::Model::ConnectionType;
-$GeoIP2::Model::ConnectionType::VERSION = '2.000001';
+$GeoIP2::Model::ConnectionType::VERSION = '2.001000';
 use strict;
 use warnings;
 
@@ -29,7 +29,7 @@ GeoIP2::Model::ConnectionType - Model class for the GeoIP2 Connection Type datab
 
 =head1 VERSION
 
-version 2.000001
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -37,25 +37,26 @@ version 2.000001
 
   use GeoIP2::Model::ConnectionType;
 
-  my $record = GeoIP2::Model::ConnectionType->new(
+  my $conn = GeoIP2::Model::ConnectionType->new(
       raw => { connection_type => 'Corporate', ip_address => '24.24.24.24'}
   );
 
-  say $record->connection_type();
+  say $conn->connection_type();
 
 =head1 DESCRIPTION
 
-This class provides a model for GeoIP2 Connection-Type.
+This class provides a model for the data returned by the GeoIP2 Connection
+Type database.
 
 =head1 METHODS
 
 This class provides the following methods:
 
-=head2 $record->connection_type()
+=head2 $conn->connection_type()
 
 Returns the connection type as a string.
 
-=head2 $record->ip_address()
+=head2 $conn->ip_address()
 
 Returns the IP address used in the lookup.
 
@@ -79,7 +80,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
