@@ -1,5 +1,5 @@
 package GeoIP2::Model::ISP;
-$GeoIP2::Model::ISP::VERSION = '2.000001';
+$GeoIP2::Model::ISP::VERSION = '2.001000';
 use strict;
 use warnings;
 
@@ -47,7 +47,7 @@ GeoIP2::Model::ISP - Model class for the GeoIP2 ISP database
 
 =head1 VERSION
 
-version 2.000001
+version 2.001000
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ version 2.000001
 
   use GeoIP2::Model::ISP;
 
-  my $record = GeoIP2::Model::ISP->new(
+  my $isp = GeoIP2::Model::ISP->new(
       raw => {
           autonomous_system_number => '217',
           autonomous_system_organization => 'University of Minnesota',
@@ -65,40 +65,40 @@ version 2.000001
       }
   );
 
-  say $record->autonomous_system_number();
-  say $record->autonomous_system_organization();
-  say $record->isp();
-  say $record->organization();
+  say $isp->autonomous_system_number();
+  say $isp->autonomous_system_organization();
+  say $isp->isp();
+  say $isp->organization();
 
 =head1 DESCRIPTION
 
-This class provides a model for GeoIP2 Connection-Type.
+This class provides a model for the data returned by the GeoIP2 ISP database.
 
 =head1 METHODS
 
 This class provides the following methods:
 
-=head2 $record->autonomous_system_number()
+=head2 $isp->autonomous_system_number()
 
 This returns the autonomous system number
 (L<http://en.wikipedia.org/wiki/Autonomous_system_(Internet)>) associated with
 the IP address.
 
-=head2 $record->autonomous_system_organization()
+=head2 $isp->autonomous_system_organization()
 
 This returns the organization associated with the registered autonomous system
 number (L<http://en.wikipedia.org/wiki/Autonomous_system_(Internet)>) for the IP
 address.
 
-=head2 $record->ip_address()
+=head2 $isp->ip_address()
 
 Returns the IP address used in the lookup.
 
-=head2 $record->isp()
+=head2 $isp->isp()
 
 This returns the name of the ISP associated with the IP address.
 
-=head2 $record->organization()
+=head2 $isp->organization()
 
 This returns the name of the organization associated with the IP address.
 
@@ -122,7 +122,7 @@ Olaf Alders <oalders@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by MaxMind, Inc..
+This software is copyright (c) 2013 - 2014 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
